﻿const dgram = require("dgram");
const express = require("express");
const path = require("path");

const app = express();

const SERVERS = 
[
    { ip: "160.25.82.90", port: 27017, hostname: "[#1] PvP 5v5 | by The Checkmate", maxPlayers: 12},
    { ip: "160.25.82.90", port: 2, hostname: "[#2] Retake | by The Checkmate", maxPlayers: 10},
];

app.use(express.static(path.join(__dirname, "public")));

function queryServer(ip, port, hostname, maxPlayers, map) {
    return new Promise((resolve, reject) => {
        const socket = dgram.createSocket("udp4");
        const A2S_INFO = Buffer.from([0xFF, 0xFF, 0xFF, 0xFF, 0x54, ...Buffer.from("Source Engine Query"), 0x00]);

        let receivedChallenge = null;

        socket.on("message", (msg) => {
            if (msg[4] === 0x41) {
                receivedChallenge = msg.slice(5);
                const A2S_PLAYER = Buffer.concat([Buffer.from([0xFF, 0xFF, 0xFF, 0xFF, 0x55]), receivedChallenge]);
                socket.send(A2S_PLAYER, 0, A2S_PLAYER.length, port, ip);
            } else if (msg[4] === 0x44) {
                const playerCount = msg[5];
                resolve({ ip, port, hostname, map, players: playerCount, maxPlayers });
                socket.close();
            } else if (msg[4] === 0x49) {
                const mapIndex = msg.indexOf(0x00, 6);
                const mapName = msg.toString("utf8", mapIndex + 1, msg.indexOf(0x00, mapIndex + 1));
                const players = msg[mapIndex + mapName.length + 2];
                const maxPlayers = msg[mapIndex + mapName.length + 3];
                resolve({ ip, port, hostname, map: mapName, players, maxPlayers });
                socket.close();
            }
        });

        socket.on("error", (err) => {
            reject({ ip, port, error: err.message });
            socket.close();
        });

        socket.send(A2S_INFO, 0, A2S_INFO.length, port, ip);
    });
}

app.get("/api/server-info", async (req, res) => {
    try {
        const serverPromises = SERVERS.map(server => queryServer(server.ip, server.port, server.hostname, server.maxPlayers, server.map));
        const serverInfo = await Promise.allSettled(serverPromises);

        const results = serverInfo.map(result =>
            result.status === "fulfilled" ? result.value : { ip: result.reason.ip, port: result.reason.port, error: result.reason.error }
        );

        res.json(results);
    } catch (error) {
        console.error("Error:", error);
        res.status(500).json({ error: "Không thể lấy thông tin server @@" });
    }
});

app.get("/", (req, res) => {
    res.sendFile(path.join(__dirname, "public", "server.html"));
});

app.listen(27000, () => {
    console.log("Server listening on http://160.25.82.90:27000");
});
